
/*
* ============================================================================
*  Name     : CCircle from circle.h
*  Part of  : plugin
*  Created  : 17/11/2003 by Forum Nokia
*  Description:
*     Implements the drawing of a circle
*  Version  : 1.0
*  Copyright: Forum Nokia
* ============================================================================
*/

#ifndef __CIRCLE_H__
#define __CIRCLE_H__

// INCLUDES
#include <shapeinterface.h>

/**
 * Class:       CCircle
 *
 * Description: An implementation of the CShape definition. Displays a circle
 *              shape to screen. This is concrete class, instance of which
 *              ECOM framework gives to ECOM clients.
 */
class CCircle : public CShape
	{
public:
	/**
     * Function:    NewL
     *
     * Description: Create instance of concrete implementation. Note that ECOM
     *              interface implementations can only have two signatures for
     *              NewL:
     *               - NewL without parameters (used here)
     *               - NewL with TAny* pointer, which may provide some client
     *                 data
     *
     * Returns:    Instance of this class.
     *
     * Note:       The interface, which is abstract base class of this
     *             implementation, also provides NewL method. Normally abstract
     *             classes do not provide NewL, because they cannot create
     *             instances of themselves.
     */
	static CCircle* NewL();

public: // CShape
	/**
     * Function:    ConstructL
     *
     * Description: Draws shape of object
	 *
	 * Param:       aGraphicsContext graphics context to display result
     */
	virtual void Draw(CWindowGc& aGraphicsContext) const;

protected:
	/**
     * Function:   CCircle
     *
     * Discussion: Perform the first phase of two phase construction
     */
	CCircle();
	
	/**
     * Function:   ConstructL
     *
     * Discussion: Perform the second phase construction of a
     *             CImplementationClassPlus object.
     */
	void ConstructL();
	};

#endif

